@@ -1,5 +1,4 @@
 from typing import List
-from functools import lru_cache
 from .tokens import *
 
 
@@ -15,7 +14,6 @@ class Lexer:
     def __is_digit__(self, ch: str) -> bool:
         return self.__digits__.find(ch) > -1
 
-    @lru_cache(maxsize=4)
     def scan(self, re: str) -> List[Token]:
         """ Regular expressions scanner.
 
@@ -43,7 +41,7 @@ class Lexer:
                     append(ElementToken(char='\t'))
                 if ch == 's':
                     # \s matches a space character
-                    append(SpaceToken(space_ch=ch))
+                    append(SpaceToken(char=ch))
                 else:
                     append(ElementToken(char=ch))
             elif ch == '\\':
@@ -75,7 +73,7 @@ class Lexer:
                         append(RightCurlyBrace())
                         break
                     else:
-                        raise Exception('Bad token at index ${}.'.format(i))
+                        raise Exception("Bad token at index ${}.".format(i))
                     i += 1
             elif ch == '^':
                 if i == 0:
